@@ -175,7 +175,7 @@ int
 Dde_Init(
     Tcl_Interp *interp)
 {
-    if (!Tcl_InitStubs(interp, "8.5", 0)) {
+    if (!Tcl_InitStubs(interp, "8.5-", 0)) {
 	return TCL_ERROR;
     }
 
@@ -868,7 +868,7 @@ DdeServerProc(
     case XTYP_EXECUTE: {
 	/*
 	 * Execute this script. The results will be saved into a list object
-	 * which will be retreived later. See ExecuteRemoteObject.
+	 * which will be retrieved later. See ExecuteRemoteObject.
 	 */
 
 	Tcl_Obj *returnPackagePtr;
@@ -891,13 +891,13 @@ DdeServerProc(
 	    /* Empty binary array. */
 	    ddeObjectPtr = Tcl_NewObj();
 	} else if ((dlen & 1) || utilString[(dlen>>1)-1]) {
-	    /* Cannot be unicode, so assume utf-8 */
+	    /* Cannot be Unicode, so assume utf-8 */
 	    if (!string[dlen-1]) {
 		dlen--;
 	    }
 	    ddeObjectPtr = Tcl_NewStringObj(string, dlen);
 	} else {
-	    /* unicode */
+	    /* Unicode */
 	    Tcl_DString dsBuf;
 
 	    Tcl_DStringInit(&dsBuf);
@@ -1299,8 +1299,7 @@ DdeObjCmd(
     Tcl_Obj *const *objv)	/* The arguments */
 {
     static const char *const ddeCommands[] = {
-	"servername", "execute", "poke", "request", "services", "eval",
-	(char *) NULL};
+	"servername", "execute", "poke", "request", "services", "eval", NULL};
     enum DdeSubcommands {
 	DDE_SERVERNAME, DDE_EXECUTE, DDE_POKE, DDE_REQUEST, DDE_SERVICES,
 	DDE_EVAL
